Cortex CLI
##########

:Release: |release|
:Date: |today|

Command-line tool (CLI) for interacting with IQM quantum computers.

Contents
--------

.. toctree::
   :maxdepth: 2

   Readme <readme>
   License <license>
   Authors <authors>
   Changelog <changelog>

Indices
=======

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
